/**
 * This file represents the pulsararchive database in mysql++
 **/


#include <mysql++.h>
#include <Pulsar/Archive.h>



using mysqlpp::Exception;
using mysqlpp::Connection;
using mysqlpp::sql_int;
using mysqlpp::sql_bigint;
using mysqlpp::sql_char;
using mysqlpp::sql_double;
using mysqlpp::sql_float;
using std::string;
using std::vector;
using Pulsar::Archive;





struct ObservationEntry
{
  string filename;
  string data_loc;
  char prefix;
  vector<string> files;
};

struct ObservationDetails
{
  double obsfreq;
  double bw;
};




/**
 * Exceptions the database might throw
 **/

class MYSQLPP_EXPORT FailedConnection : public Exception
{
  public:
    explicit FailedConnection(const char* w = "Unable to connect to database") : Exception(w) { }
};

class MYSQLPP_EXPORT GenericException : public Exception
{
  public:
    explicit GenericException( const char *w = "Unknown Expception" ) : Exception(w) { }
};





class psrdb
{
  public:
    psrdb();
    
    void Connect( const char *db_name, const char *db_hostname, const char *db_username, const char *db_password );
    
    void MarkObservations();
    
    void GetArchiveDetails( ObservationDetails &details, Reference::To<Archive> arch );
    
    void PurgeMissingObservations();
    void PurgeMissingCals();
    
    void GetObsDetails( const ObservationEntry &entry, ObservationDetails &details );
    
    void CheckObservation( const ObservationEntry &details );
    
  private:
    Connection db;
};



